Rohde & Schwarz python instrument control toolkit
=================================================

This package provides classes for controlling Rohde & Schwarz general purpose instruments in a pythonic way.